@@ -150,6 +150,17 @@ class File(object):
     @classmethod
     def mv(cls, src, dest, overwrite=False):
         return mv(src, dest, overwrite)
+    
+    @classmethod
+    def fmv(cls, src, directory, overwrite=False):
+        dest = File.join(directory, File.base(src))
+        if not File.exists(dest) or overwrite:
+            logger.info(f'Moving File {src} -> {dest}')
+            File.mv(src, dest)
+        else:    
+            logger.error(f'Error: File Destination {dest} exists. Not Moving.')
+        return dest
+
 
     @classmethod
     def rm(cls, filename):
@@ -198,6 +209,14 @@ class File(object):
             return File.join(directory, afilename)
         return afilename
     
+    @classmethod
+    def change_ext(cls, filepath, ext, directory=None):
+        filename = File.base(filepath)
+        ext_file = filename.split('.', 1)[0] + '.' + ext
+        if directory:
+            return File.join(directory, ext_file)
+        return ext_file
+
     @classmethod
     def findir(cls, filepath, directory):
         filename = File.base(filepath)
@@ -519,7 +538,7 @@ class File(object):
         with gfile(filename, mode) as f:
             for x, d in enumerate(data):
                 try:
-                    File.jldump(d, f)
+                    File.jldumps(d, f)
                     _good += 1
                 except StopIteration:
                     break
